@@ -101,11 +101,11 @@ pub enum CanonicalizationResult {
 /// [`CLDR`]: http://cldr.unicode.org/
 /// [`UTS #35: Unicode LDML 3. Likely Subtags`]: https://www.unicode.org/reports/tr35/#Likely_Subtags.
 /// [`UTS #35: Unicode LDML 3. LocaleId Canonicalization`]: http://unicode.org/reports/tr35/#LocaleId_Canonicalization,
-pub struct LocaleCanonicalizer<'data> {
+pub struct LocaleCanonicalizer {
     /// Data to support canonicalization.
-    aliases: DataPayload<'data, AliasesV1Marker>,
+    aliases: DataPayload<AliasesV1Marker>,
     /// Data to support likely subtags maximize and minimize.
-    likely_subtags: DataPayload<'data, LikelySubtagsV1Marker>,
+    likely_subtags: DataPayload<LikelySubtagsV1Marker>,
     /// Extension keys that require canonicalization.
     extension_keys: Vec<Key>,
 }
@@ -187,36 +187,48 @@ fn update_langid(
     entry: &LanguageIdentifier,
     langid: &mut LanguageIdentifier,
 ) -> CanonicalizationResult {
-    if langid.language.is_empty() {
+    let mut modified = false;
+
+    if langid.language.is_empty() && !entry.language.is_empty() {
         langid.language = entry.language;
+        modified = true;
+    }
+
+    if langid.script.is_none() && entry.script.is_some() {
+        langid.script = entry.script;
+        modified = true;
+    }
+
+    if langid.region.is_none() && entry.region.is_some() {
+        langid.region = entry.region;
+        modified = true;
+    }
+
+    if modified {
+        CanonicalizationResult::Modified
+    } else {
+        CanonicalizationResult::Unmodified
     }
-    langid.script = langid.script.or(entry.script);
-    langid.region = langid.region.or(entry.region);
-    CanonicalizationResult::Modified
 }
 
 macro_rules! maximize_locale {
     ( $langid:ident, $table:expr, $key:expr ) => {{
-        if let Ok(index) = $table.binary_search_by_key(&&$key, |(i1, _)| i1) {
-            let entry = &$table[index].1;
-            return update_langid(entry, $langid);
+        if let Some(language_identifier) = $table.get(&&$key) {
+            return update_langid(language_identifier, $langid);
         }
     }};
     ( $langid:ident, $table:expr, $key1:expr, $key2:expr ) => {{
-        if let Ok(index) = $table.binary_search_by_key(&(&$key1, &$key2), |(i1, i2, _)| (i1, i2)) {
-            let entry = &$table[index].2;
-            return update_langid(entry, $langid);
+        if let Some(language_identifier) = $table.get(&($key1, $key2)) {
+            return update_langid(language_identifier, $langid);
         }
     }};
 }
 
-impl<'data> LocaleCanonicalizer<'data> {
+impl LocaleCanonicalizer {
     /// A constructor which takes a [`DataProvider`] and creates a [`LocaleCanonicalizer`].
-    pub fn new<P>(provider: &P) -> Result<LocaleCanonicalizer<'data>, DataError>
+    pub fn new<P>(provider: &P) -> Result<LocaleCanonicalizer, DataError>
     where
-        P: DataProvider<'data, AliasesV1Marker>
-            + DataProvider<'data, LikelySubtagsV1Marker>
-            + ?Sized,
+        P: DataProvider<AliasesV1Marker> + DataProvider<LikelySubtagsV1Marker> + ?Sized,
     {
         // The `rg` region override and `sd` regional subdivision keys may contain
         // language codes that require canonicalization.
@@ -241,7 +253,7 @@ impl<'data> LocaleCanonicalizer<'data> {
 
     /// The canonicalize method potentially updates a passed in locale in place
     /// depending up the results of running the canonicalization algorithm
-    /// from http://unicode.org/reports/tr35/#LocaleId_Canonicalization
+    /// from <http://unicode.org/reports/tr35/#LocaleId_Canonicalization>.
     ///
     /// Some BCP47 canonicalization data is not part of the CLDR json package. Because
     /// of this, some canonicalizations are not performed, e.g. the canonicalization of
@@ -490,7 +502,7 @@ impl<'data> LocaleCanonicalizer<'data> {
 
     /// The maximize method potentially updates a passed in locale in place
     /// depending up the results of running the 'Add Likely Subtags' algorithm
-    /// from https://www.unicode.org/reports/tr35/#Likely_Subtags.
+    /// from <https://www.unicode.org/reports/tr35/#Likely_Subtags>.
     ///
     /// If the result of running the algorithm would result in a new locale, the
     /// locale argument is updated in place to match the result, and the method
@@ -534,12 +546,14 @@ impl<'data> LocaleCanonicalizer<'data> {
                 maximize_locale!(langid, data.language_script, language, script.into());
             }
             maximize_locale!(langid, data.language, language);
-        } else if let Some(script) = langid.script {
+        }
+        if let Some(script) = langid.script {
             if let Some(region) = langid.region {
                 maximize_locale!(langid, data.script_region, script.into(), region.into());
             }
             maximize_locale!(langid, data.script, script.into());
-        } else if let Some(region) = langid.region {
+        }
+        if let Some(region) = langid.region {
             maximize_locale!(langid, data.region, region.into());
         }
         update_langid(&data.und, langid)
@@ -547,7 +561,7 @@ impl<'data> LocaleCanonicalizer<'data> {
 
     /// This returns a new Locale that is the result of running the
     /// 'Remove Likely Subtags' algorithm from
-    /// https://www.unicode.org/reports/tr35/#Likely_Subtags.
+    /// <https://www.unicode.org/reports/tr35/#Likely_Subtags>.
     ///
     /// If the result of running the algorithm would result in a new locale, the
     /// locale argument is updated in place to match the result, and the method
