@@ -9,16 +9,18 @@
 use alloc::vec::Vec;
 use icu_locid::LanguageIdentifier;
 use icu_provider::yoke::{self, *};
+use litemap::LiteMap;
 use tinystr::{TinyStr4, TinyStr8};
 
-/// A collection of [`ResourceKey`] structs for LocaleCanonicalizer providers.
+/// A collection of [`ResourceKey`](icu_provider::ResourceKey) structs for
+/// LocaleCanonicalizer providers.
 pub mod key {
     use icu_provider::{resource_key, ResourceKey};
     /// Key for aliases data.
-    pub const ALIASES_V1: ResourceKey = resource_key!(LocaleCanonicalizer, "aliases", 1);
+    pub const ALIASES_V1: ResourceKey = resource_key!("locale_canonicalizer/aliases@1");
     /// Key for likely subtags data.
     pub const LIKELY_SUBTAGS_V1: ResourceKey =
-        resource_key!(LocaleCanonicalizer, "likelysubtags", 1);
+        resource_key!("locale_canonicalizer/likelysubtags@1");
 }
 
 #[icu_provider::data_struct]
@@ -30,7 +32,7 @@ pub mod key {
 #[yoke(cloning_zcf)]
 /// This alias data is used for locale canonicalization. Each field defines a
 /// mapping from an old identifier to a new identifier, based upon the rules in
-/// from http://unicode.org/reports/tr35/#LocaleId_Canonicalization. The data
+/// from <http://unicode.org/reports/tr35/#LocaleId_Canonicalization>. The data
 /// is stored in sorted order, allowing for binary search to identify rules to
 /// apply. It is broken down into smaller vectors based upon some characteristic
 /// of the data, to help avoid unnecessary searches. For example, the `sgn_region`
@@ -75,7 +77,7 @@ pub struct AliasesV1 {
 /// This likely subtags data is used for the minimize and maximize operations.
 /// Each field defines a mapping from an old identifier to a new identifier,
 /// based upon the rules in
-/// https://www.unicode.org/reports/tr35/#Likely_Subtags.
+/// <https://www.unicode.org/reports/tr35/#Likely_Subtags>.
 ///
 /// The data is stored in sorted order, allowing for binary search to identify
 /// rules to apply. It is broken down into smaller vectors based upon the rules
@@ -88,17 +90,17 @@ pub struct AliasesV1 {
 /// `LanguageIdentifier`.
 pub struct LikelySubtagsV1 {
     /// Language and script.
-    pub language_script: Vec<(TinyStr4, TinyStr4, LanguageIdentifier)>,
+    pub language_script: LiteMap<(TinyStr4, TinyStr4), LanguageIdentifier>,
     /// Language and region.
-    pub language_region: Vec<(TinyStr4, TinyStr4, LanguageIdentifier)>,
+    pub language_region: LiteMap<(TinyStr4, TinyStr4), LanguageIdentifier>,
     /// Just language.
-    pub language: Vec<(TinyStr4, LanguageIdentifier)>,
+    pub language: LiteMap<TinyStr4, LanguageIdentifier>,
     /// Script and region.
-    pub script_region: Vec<(TinyStr4, TinyStr4, LanguageIdentifier)>,
+    pub script_region: LiteMap<(TinyStr4, TinyStr4), LanguageIdentifier>,
     /// Just script.
-    pub script: Vec<(TinyStr4, LanguageIdentifier)>,
+    pub script: LiteMap<TinyStr4, LanguageIdentifier>,
     /// Just region.
-    pub region: Vec<(TinyStr4, LanguageIdentifier)>,
+    pub region: LiteMap<TinyStr4, LanguageIdentifier>,
     /// Undefined.
     pub und: LanguageIdentifier,
 }
